@@ -22,6 +22,7 @@
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QIcon>
+#include <QDir>
 
 
 KPartLoaderWindow::KPartLoaderWindow(const QString& partLib)
@@ -37,12 +38,19 @@ KPartLoaderWindow::KPartLoaderWindow(const QString& partLib)
     a->setText(i18n("&About KPart..."));
     connect(a, SIGNAL(triggered()), this, SLOT(aboutKPart()));
 
-    KPluginFactory *factory = KPluginFactory::loadFactory(KPluginMetaData(partLib)).plugin;
+    auto factory = KPluginFactory::loadFactory(KPluginMetaData(partLib));
+    if (!factory && !partLib.contains('/')) {
+        qDebug() << "No part named" << partLib << "found directly, trying to load from kf6/parts/";
+        auto fallback = KPluginFactory::loadFactory(KPluginMetaData(QLatin1String("kf6/parts/") + partLib));
+        if (fallback)
+            factory = fallback;
+    }
+
     if (factory) {
         // Create the part
-        m_part = factory->create<KParts::ReadOnlyPart>(this, this);
+        m_part = factory.plugin->create<KParts::ReadOnlyPart>(this, this);
     } else {
-        KMessageBox::error(this, i18n("No part named %1 found.", partLib));
+        KMessageBox::error(this, i18n("No part named %1 found: %2", partLib, factory.errorString));
     }
 
     if (m_part) {
@@ -85,6 +93,9 @@ int main( int argc, char **argv )
     aboutData.setupCommandLine(&parser);
     parser.addPositionalArgument(QLatin1String("part"), i18n("Name of the part to load, e.g. dolphinpart"));
 
+    QCommandLineOption url("url", "URL to open in the KPart", "url");
+    parser.addOption(url);
+
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
@@ -93,6 +104,13 @@ int main( int argc, char **argv )
     {
         KPartLoaderWindow *shell = new KPartLoaderWindow(args.at(0));
         shell->show();
+
+        if (parser.isSet(url)) {
+            shell->part()->openUrl(QUrl::fromUserInput(parser.value(url),
+                                                       QDir::currentPath(),
+                                                       QUrl::AssumeLocalFile));
+        }
+
         return app.exec();
     }
     return -1;
